# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class CapabilitiesEnum(str, Enum):
    """
    CapabilitiesEnum
    """

    """
    allowed enum values
    """
    CAN_SAVE_MEDIA = 'can_save_media'
    CAN_GEO_IP = 'can_geo_ip'
    CAN_ASN = 'can_asn'
    CAN_IMPERSONATE = 'can_impersonate'
    CAN_DEBUG = 'can_debug'
    IS_ENTERPRISE = 'is_enterprise'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CapabilitiesEnum from a JSON string"""
        return cls(json.loads(json_str))


