# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.google_workspace_provider_mapping import GoogleWorkspaceProviderMapping

class TestGoogleWorkspaceProviderMapping(unittest.TestCase):
    """GoogleWorkspaceProviderMapping unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleWorkspaceProviderMapping:
        """Test GoogleWorkspaceProviderMapping
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleWorkspaceProviderMapping`
        """
        model = GoogleWorkspaceProviderMapping()
        if include_optional:
            return GoogleWorkspaceProviderMapping(
                pk = '',
                managed = '',
                name = '',
                expression = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = ''
            )
        else:
            return GoogleWorkspaceProviderMapping(
                pk = '',
                name = '',
                expression = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
        )
        """

    def testGoogleWorkspaceProviderMapping(self):
        """Test GoogleWorkspaceProviderMapping"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
