# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_prompt_list import PaginatedPromptList

class TestPaginatedPromptList(unittest.TestCase):
    """PaginatedPromptList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedPromptList:
        """Test PaginatedPromptList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedPromptList`
        """
        model = PaginatedPromptList()
        if include_optional:
            return PaginatedPromptList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.prompt.Prompt(
                        pk = '', 
                        name = '', 
                        field_key = '', 
                        label = '', 
                        type = 'text', 
                        required = True, 
                        placeholder = '', 
                        initial_value = '', 
                        order = -2147483648, 
                        promptstage_set = [
                            authentik_client.models.stage.Stage(
                                pk = '', 
                                name = '', 
                                component = '', 
                                verbose_name = '', 
                                verbose_name_plural = '', 
                                meta_model_name = '', 
                                flow_set = [
                                    authentik_client.models.flow_set.FlowSet(
                                        pk = '', 
                                        policybindingmodel_ptr_id = '', 
                                        name = '', 
                                        slug = 'z', 
                                        title = '', 
                                        designation = null, 
                                        background = '', 
                                        policy_engine_mode = 'all', 
                                        compatibility_mode = True, 
                                        export_url = '', 
                                        layout = 'stacked', 
                                        denied_action = null, )
                                    ], )
                            ], 
                        sub_text = '', 
                        placeholder_expression = True, 
                        initial_value_expression = True, )
                    ],
                autocomplete = {
                    'key' : null
                    }
            )
        else:
            return PaginatedPromptList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.prompt.Prompt(
                        pk = '', 
                        name = '', 
                        field_key = '', 
                        label = '', 
                        type = 'text', 
                        required = True, 
                        placeholder = '', 
                        initial_value = '', 
                        order = -2147483648, 
                        promptstage_set = [
                            authentik_client.models.stage.Stage(
                                pk = '', 
                                name = '', 
                                component = '', 
                                verbose_name = '', 
                                verbose_name_plural = '', 
                                meta_model_name = '', 
                                flow_set = [
                                    authentik_client.models.flow_set.FlowSet(
                                        pk = '', 
                                        policybindingmodel_ptr_id = '', 
                                        name = '', 
                                        slug = 'z', 
                                        title = '', 
                                        designation = null, 
                                        background = '', 
                                        policy_engine_mode = 'all', 
                                        compatibility_mode = True, 
                                        export_url = '', 
                                        layout = 'stacked', 
                                        denied_action = null, )
                                    ], )
                            ], 
                        sub_text = '', 
                        placeholder_expression = True, 
                        initial_value_expression = True, )
                    ],
                autocomplete = {
                    'key' : null
                    },
        )
        """

    def testPaginatedPromptList(self):
        """Test PaginatedPromptList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
