# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.outposts_api import OutpostsApi


class TestOutpostsApi(unittest.TestCase):
    """OutpostsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OutpostsApi()

    def tearDown(self) -> None:
        pass

    def test_outposts_instances_create(self) -> None:
        """Test case for outposts_instances_create

        """
        pass

    def test_outposts_instances_default_settings_retrieve(self) -> None:
        """Test case for outposts_instances_default_settings_retrieve

        """
        pass

    def test_outposts_instances_destroy(self) -> None:
        """Test case for outposts_instances_destroy

        """
        pass

    def test_outposts_instances_health_list(self) -> None:
        """Test case for outposts_instances_health_list

        """
        pass

    def test_outposts_instances_list(self) -> None:
        """Test case for outposts_instances_list

        """
        pass

    def test_outposts_instances_partial_update(self) -> None:
        """Test case for outposts_instances_partial_update

        """
        pass

    def test_outposts_instances_retrieve(self) -> None:
        """Test case for outposts_instances_retrieve

        """
        pass

    def test_outposts_instances_update(self) -> None:
        """Test case for outposts_instances_update

        """
        pass

    def test_outposts_instances_used_by_list(self) -> None:
        """Test case for outposts_instances_used_by_list

        """
        pass

    def test_outposts_ldap_access_check(self) -> None:
        """Test case for outposts_ldap_access_check

        """
        pass

    def test_outposts_ldap_list(self) -> None:
        """Test case for outposts_ldap_list

        """
        pass

    def test_outposts_proxy_list(self) -> None:
        """Test case for outposts_proxy_list

        """
        pass

    def test_outposts_radius_access_check(self) -> None:
        """Test case for outposts_radius_access_check

        """
        pass

    def test_outposts_radius_list(self) -> None:
        """Test case for outposts_radius_list

        """
        pass

    def test_outposts_service_connections_all_destroy(self) -> None:
        """Test case for outposts_service_connections_all_destroy

        """
        pass

    def test_outposts_service_connections_all_list(self) -> None:
        """Test case for outposts_service_connections_all_list

        """
        pass

    def test_outposts_service_connections_all_retrieve(self) -> None:
        """Test case for outposts_service_connections_all_retrieve

        """
        pass

    def test_outposts_service_connections_all_state_retrieve(self) -> None:
        """Test case for outposts_service_connections_all_state_retrieve

        """
        pass

    def test_outposts_service_connections_all_types_list(self) -> None:
        """Test case for outposts_service_connections_all_types_list

        """
        pass

    def test_outposts_service_connections_all_used_by_list(self) -> None:
        """Test case for outposts_service_connections_all_used_by_list

        """
        pass

    def test_outposts_service_connections_docker_create(self) -> None:
        """Test case for outposts_service_connections_docker_create

        """
        pass

    def test_outposts_service_connections_docker_destroy(self) -> None:
        """Test case for outposts_service_connections_docker_destroy

        """
        pass

    def test_outposts_service_connections_docker_list(self) -> None:
        """Test case for outposts_service_connections_docker_list

        """
        pass

    def test_outposts_service_connections_docker_partial_update(self) -> None:
        """Test case for outposts_service_connections_docker_partial_update

        """
        pass

    def test_outposts_service_connections_docker_retrieve(self) -> None:
        """Test case for outposts_service_connections_docker_retrieve

        """
        pass

    def test_outposts_service_connections_docker_update(self) -> None:
        """Test case for outposts_service_connections_docker_update

        """
        pass

    def test_outposts_service_connections_docker_used_by_list(self) -> None:
        """Test case for outposts_service_connections_docker_used_by_list

        """
        pass

    def test_outposts_service_connections_kubernetes_create(self) -> None:
        """Test case for outposts_service_connections_kubernetes_create

        """
        pass

    def test_outposts_service_connections_kubernetes_destroy(self) -> None:
        """Test case for outposts_service_connections_kubernetes_destroy

        """
        pass

    def test_outposts_service_connections_kubernetes_list(self) -> None:
        """Test case for outposts_service_connections_kubernetes_list

        """
        pass

    def test_outposts_service_connections_kubernetes_partial_update(self) -> None:
        """Test case for outposts_service_connections_kubernetes_partial_update

        """
        pass

    def test_outposts_service_connections_kubernetes_retrieve(self) -> None:
        """Test case for outposts_service_connections_kubernetes_retrieve

        """
        pass

    def test_outposts_service_connections_kubernetes_update(self) -> None:
        """Test case for outposts_service_connections_kubernetes_update

        """
        pass

    def test_outposts_service_connections_kubernetes_used_by_list(self) -> None:
        """Test case for outposts_service_connections_kubernetes_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
