# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_web_authn_stage import AuthenticatorWebAuthnStage

class TestAuthenticatorWebAuthnStage(unittest.TestCase):
    """AuthenticatorWebAuthnStage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorWebAuthnStage:
        """Test AuthenticatorWebAuthnStage
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorWebAuthnStage`
        """
        model = AuthenticatorWebAuthnStage()
        if include_optional:
            return AuthenticatorWebAuthnStage(
                pk = '',
                name = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                flow_set = [
                    authentik_client.models.flow_set.FlowSet(
                        pk = '', 
                        policybindingmodel_ptr_id = '', 
                        name = '', 
                        slug = 'z', 
                        title = '', 
                        designation = null, 
                        background = '', 
                        policy_engine_mode = 'all', 
                        compatibility_mode = True, 
                        export_url = '', 
                        layout = 'stacked', 
                        denied_action = null, )
                    ],
                configure_flow = '',
                friendly_name = '',
                user_verification = 'required',
                authenticator_attachment = 'platform',
                resident_key_requirement = 'discouraged',
                device_type_restrictions = [
                    ''
                    ],
                device_type_restrictions_obj = [
                    authentik_client.models.web_authn_device_type.WebAuthnDeviceType(
                        aaguid = '', 
                        description = '', )
                    ],
                max_attempts = 0
            )
        else:
            return AuthenticatorWebAuthnStage(
                pk = '',
                name = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                device_type_restrictions_obj = [
                    authentik_client.models.web_authn_device_type.WebAuthnDeviceType(
                        aaguid = '', 
                        description = '', )
                    ],
        )
        """

    def testAuthenticatorWebAuthnStage(self):
        """Test AuthenticatorWebAuthnStage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
