# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.stages_api import StagesApi


class TestStagesApi(unittest.TestCase):
    """StagesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StagesApi()

    def tearDown(self) -> None:
        pass

    def test_stages_all_destroy(self) -> None:
        """Test case for stages_all_destroy

        """
        pass

    def test_stages_all_list(self) -> None:
        """Test case for stages_all_list

        """
        pass

    def test_stages_all_retrieve(self) -> None:
        """Test case for stages_all_retrieve

        """
        pass

    def test_stages_all_types_list(self) -> None:
        """Test case for stages_all_types_list

        """
        pass

    def test_stages_all_used_by_list(self) -> None:
        """Test case for stages_all_used_by_list

        """
        pass

    def test_stages_all_user_settings_list(self) -> None:
        """Test case for stages_all_user_settings_list

        """
        pass

    def test_stages_authenticator_duo_create(self) -> None:
        """Test case for stages_authenticator_duo_create

        """
        pass

    def test_stages_authenticator_duo_destroy(self) -> None:
        """Test case for stages_authenticator_duo_destroy

        """
        pass

    def test_stages_authenticator_duo_enrollment_status_create(self) -> None:
        """Test case for stages_authenticator_duo_enrollment_status_create

        """
        pass

    def test_stages_authenticator_duo_import_device_manual_create(self) -> None:
        """Test case for stages_authenticator_duo_import_device_manual_create

        """
        pass

    def test_stages_authenticator_duo_import_devices_automatic_create(self) -> None:
        """Test case for stages_authenticator_duo_import_devices_automatic_create

        """
        pass

    def test_stages_authenticator_duo_list(self) -> None:
        """Test case for stages_authenticator_duo_list

        """
        pass

    def test_stages_authenticator_duo_partial_update(self) -> None:
        """Test case for stages_authenticator_duo_partial_update

        """
        pass

    def test_stages_authenticator_duo_retrieve(self) -> None:
        """Test case for stages_authenticator_duo_retrieve

        """
        pass

    def test_stages_authenticator_duo_update(self) -> None:
        """Test case for stages_authenticator_duo_update

        """
        pass

    def test_stages_authenticator_duo_used_by_list(self) -> None:
        """Test case for stages_authenticator_duo_used_by_list

        """
        pass

    def test_stages_authenticator_email_create(self) -> None:
        """Test case for stages_authenticator_email_create

        """
        pass

    def test_stages_authenticator_email_destroy(self) -> None:
        """Test case for stages_authenticator_email_destroy

        """
        pass

    def test_stages_authenticator_email_list(self) -> None:
        """Test case for stages_authenticator_email_list

        """
        pass

    def test_stages_authenticator_email_partial_update(self) -> None:
        """Test case for stages_authenticator_email_partial_update

        """
        pass

    def test_stages_authenticator_email_retrieve(self) -> None:
        """Test case for stages_authenticator_email_retrieve

        """
        pass

    def test_stages_authenticator_email_update(self) -> None:
        """Test case for stages_authenticator_email_update

        """
        pass

    def test_stages_authenticator_email_used_by_list(self) -> None:
        """Test case for stages_authenticator_email_used_by_list

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_create(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_create

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_destroy(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_destroy

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_list(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_list

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_partial_update(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_partial_update

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_retrieve(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_retrieve

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_update(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_update

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_used_by_list(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_used_by_list

        """
        pass

    def test_stages_authenticator_sms_create(self) -> None:
        """Test case for stages_authenticator_sms_create

        """
        pass

    def test_stages_authenticator_sms_destroy(self) -> None:
        """Test case for stages_authenticator_sms_destroy

        """
        pass

    def test_stages_authenticator_sms_list(self) -> None:
        """Test case for stages_authenticator_sms_list

        """
        pass

    def test_stages_authenticator_sms_partial_update(self) -> None:
        """Test case for stages_authenticator_sms_partial_update

        """
        pass

    def test_stages_authenticator_sms_retrieve(self) -> None:
        """Test case for stages_authenticator_sms_retrieve

        """
        pass

    def test_stages_authenticator_sms_update(self) -> None:
        """Test case for stages_authenticator_sms_update

        """
        pass

    def test_stages_authenticator_sms_used_by_list(self) -> None:
        """Test case for stages_authenticator_sms_used_by_list

        """
        pass

    def test_stages_authenticator_static_create(self) -> None:
        """Test case for stages_authenticator_static_create

        """
        pass

    def test_stages_authenticator_static_destroy(self) -> None:
        """Test case for stages_authenticator_static_destroy

        """
        pass

    def test_stages_authenticator_static_list(self) -> None:
        """Test case for stages_authenticator_static_list

        """
        pass

    def test_stages_authenticator_static_partial_update(self) -> None:
        """Test case for stages_authenticator_static_partial_update

        """
        pass

    def test_stages_authenticator_static_retrieve(self) -> None:
        """Test case for stages_authenticator_static_retrieve

        """
        pass

    def test_stages_authenticator_static_update(self) -> None:
        """Test case for stages_authenticator_static_update

        """
        pass

    def test_stages_authenticator_static_used_by_list(self) -> None:
        """Test case for stages_authenticator_static_used_by_list

        """
        pass

    def test_stages_authenticator_totp_create(self) -> None:
        """Test case for stages_authenticator_totp_create

        """
        pass

    def test_stages_authenticator_totp_destroy(self) -> None:
        """Test case for stages_authenticator_totp_destroy

        """
        pass

    def test_stages_authenticator_totp_list(self) -> None:
        """Test case for stages_authenticator_totp_list

        """
        pass

    def test_stages_authenticator_totp_partial_update(self) -> None:
        """Test case for stages_authenticator_totp_partial_update

        """
        pass

    def test_stages_authenticator_totp_retrieve(self) -> None:
        """Test case for stages_authenticator_totp_retrieve

        """
        pass

    def test_stages_authenticator_totp_update(self) -> None:
        """Test case for stages_authenticator_totp_update

        """
        pass

    def test_stages_authenticator_totp_used_by_list(self) -> None:
        """Test case for stages_authenticator_totp_used_by_list

        """
        pass

    def test_stages_authenticator_validate_create(self) -> None:
        """Test case for stages_authenticator_validate_create

        """
        pass

    def test_stages_authenticator_validate_destroy(self) -> None:
        """Test case for stages_authenticator_validate_destroy

        """
        pass

    def test_stages_authenticator_validate_list(self) -> None:
        """Test case for stages_authenticator_validate_list

        """
        pass

    def test_stages_authenticator_validate_partial_update(self) -> None:
        """Test case for stages_authenticator_validate_partial_update

        """
        pass

    def test_stages_authenticator_validate_retrieve(self) -> None:
        """Test case for stages_authenticator_validate_retrieve

        """
        pass

    def test_stages_authenticator_validate_update(self) -> None:
        """Test case for stages_authenticator_validate_update

        """
        pass

    def test_stages_authenticator_validate_used_by_list(self) -> None:
        """Test case for stages_authenticator_validate_used_by_list

        """
        pass

    def test_stages_authenticator_webauthn_create(self) -> None:
        """Test case for stages_authenticator_webauthn_create

        """
        pass

    def test_stages_authenticator_webauthn_destroy(self) -> None:
        """Test case for stages_authenticator_webauthn_destroy

        """
        pass

    def test_stages_authenticator_webauthn_device_types_list(self) -> None:
        """Test case for stages_authenticator_webauthn_device_types_list

        """
        pass

    def test_stages_authenticator_webauthn_device_types_retrieve(self) -> None:
        """Test case for stages_authenticator_webauthn_device_types_retrieve

        """
        pass

    def test_stages_authenticator_webauthn_list(self) -> None:
        """Test case for stages_authenticator_webauthn_list

        """
        pass

    def test_stages_authenticator_webauthn_partial_update(self) -> None:
        """Test case for stages_authenticator_webauthn_partial_update

        """
        pass

    def test_stages_authenticator_webauthn_retrieve(self) -> None:
        """Test case for stages_authenticator_webauthn_retrieve

        """
        pass

    def test_stages_authenticator_webauthn_update(self) -> None:
        """Test case for stages_authenticator_webauthn_update

        """
        pass

    def test_stages_authenticator_webauthn_used_by_list(self) -> None:
        """Test case for stages_authenticator_webauthn_used_by_list

        """
        pass

    def test_stages_captcha_create(self) -> None:
        """Test case for stages_captcha_create

        """
        pass

    def test_stages_captcha_destroy(self) -> None:
        """Test case for stages_captcha_destroy

        """
        pass

    def test_stages_captcha_list(self) -> None:
        """Test case for stages_captcha_list

        """
        pass

    def test_stages_captcha_partial_update(self) -> None:
        """Test case for stages_captcha_partial_update

        """
        pass

    def test_stages_captcha_retrieve(self) -> None:
        """Test case for stages_captcha_retrieve

        """
        pass

    def test_stages_captcha_update(self) -> None:
        """Test case for stages_captcha_update

        """
        pass

    def test_stages_captcha_used_by_list(self) -> None:
        """Test case for stages_captcha_used_by_list

        """
        pass

    def test_stages_consent_create(self) -> None:
        """Test case for stages_consent_create

        """
        pass

    def test_stages_consent_destroy(self) -> None:
        """Test case for stages_consent_destroy

        """
        pass

    def test_stages_consent_list(self) -> None:
        """Test case for stages_consent_list

        """
        pass

    def test_stages_consent_partial_update(self) -> None:
        """Test case for stages_consent_partial_update

        """
        pass

    def test_stages_consent_retrieve(self) -> None:
        """Test case for stages_consent_retrieve

        """
        pass

    def test_stages_consent_update(self) -> None:
        """Test case for stages_consent_update

        """
        pass

    def test_stages_consent_used_by_list(self) -> None:
        """Test case for stages_consent_used_by_list

        """
        pass

    def test_stages_deny_create(self) -> None:
        """Test case for stages_deny_create

        """
        pass

    def test_stages_deny_destroy(self) -> None:
        """Test case for stages_deny_destroy

        """
        pass

    def test_stages_deny_list(self) -> None:
        """Test case for stages_deny_list

        """
        pass

    def test_stages_deny_partial_update(self) -> None:
        """Test case for stages_deny_partial_update

        """
        pass

    def test_stages_deny_retrieve(self) -> None:
        """Test case for stages_deny_retrieve

        """
        pass

    def test_stages_deny_update(self) -> None:
        """Test case for stages_deny_update

        """
        pass

    def test_stages_deny_used_by_list(self) -> None:
        """Test case for stages_deny_used_by_list

        """
        pass

    def test_stages_dummy_create(self) -> None:
        """Test case for stages_dummy_create

        """
        pass

    def test_stages_dummy_destroy(self) -> None:
        """Test case for stages_dummy_destroy

        """
        pass

    def test_stages_dummy_list(self) -> None:
        """Test case for stages_dummy_list

        """
        pass

    def test_stages_dummy_partial_update(self) -> None:
        """Test case for stages_dummy_partial_update

        """
        pass

    def test_stages_dummy_retrieve(self) -> None:
        """Test case for stages_dummy_retrieve

        """
        pass

    def test_stages_dummy_update(self) -> None:
        """Test case for stages_dummy_update

        """
        pass

    def test_stages_dummy_used_by_list(self) -> None:
        """Test case for stages_dummy_used_by_list

        """
        pass

    def test_stages_email_create(self) -> None:
        """Test case for stages_email_create

        """
        pass

    def test_stages_email_destroy(self) -> None:
        """Test case for stages_email_destroy

        """
        pass

    def test_stages_email_list(self) -> None:
        """Test case for stages_email_list

        """
        pass

    def test_stages_email_partial_update(self) -> None:
        """Test case for stages_email_partial_update

        """
        pass

    def test_stages_email_retrieve(self) -> None:
        """Test case for stages_email_retrieve

        """
        pass

    def test_stages_email_templates_list(self) -> None:
        """Test case for stages_email_templates_list

        """
        pass

    def test_stages_email_update(self) -> None:
        """Test case for stages_email_update

        """
        pass

    def test_stages_email_used_by_list(self) -> None:
        """Test case for stages_email_used_by_list

        """
        pass

    def test_stages_identification_create(self) -> None:
        """Test case for stages_identification_create

        """
        pass

    def test_stages_identification_destroy(self) -> None:
        """Test case for stages_identification_destroy

        """
        pass

    def test_stages_identification_list(self) -> None:
        """Test case for stages_identification_list

        """
        pass

    def test_stages_identification_partial_update(self) -> None:
        """Test case for stages_identification_partial_update

        """
        pass

    def test_stages_identification_retrieve(self) -> None:
        """Test case for stages_identification_retrieve

        """
        pass

    def test_stages_identification_update(self) -> None:
        """Test case for stages_identification_update

        """
        pass

    def test_stages_identification_used_by_list(self) -> None:
        """Test case for stages_identification_used_by_list

        """
        pass

    def test_stages_invitation_invitations_create(self) -> None:
        """Test case for stages_invitation_invitations_create

        """
        pass

    def test_stages_invitation_invitations_destroy(self) -> None:
        """Test case for stages_invitation_invitations_destroy

        """
        pass

    def test_stages_invitation_invitations_list(self) -> None:
        """Test case for stages_invitation_invitations_list

        """
        pass

    def test_stages_invitation_invitations_partial_update(self) -> None:
        """Test case for stages_invitation_invitations_partial_update

        """
        pass

    def test_stages_invitation_invitations_retrieve(self) -> None:
        """Test case for stages_invitation_invitations_retrieve

        """
        pass

    def test_stages_invitation_invitations_update(self) -> None:
        """Test case for stages_invitation_invitations_update

        """
        pass

    def test_stages_invitation_invitations_used_by_list(self) -> None:
        """Test case for stages_invitation_invitations_used_by_list

        """
        pass

    def test_stages_invitation_stages_create(self) -> None:
        """Test case for stages_invitation_stages_create

        """
        pass

    def test_stages_invitation_stages_destroy(self) -> None:
        """Test case for stages_invitation_stages_destroy

        """
        pass

    def test_stages_invitation_stages_list(self) -> None:
        """Test case for stages_invitation_stages_list

        """
        pass

    def test_stages_invitation_stages_partial_update(self) -> None:
        """Test case for stages_invitation_stages_partial_update

        """
        pass

    def test_stages_invitation_stages_retrieve(self) -> None:
        """Test case for stages_invitation_stages_retrieve

        """
        pass

    def test_stages_invitation_stages_update(self) -> None:
        """Test case for stages_invitation_stages_update

        """
        pass

    def test_stages_invitation_stages_used_by_list(self) -> None:
        """Test case for stages_invitation_stages_used_by_list

        """
        pass

    def test_stages_mtls_create(self) -> None:
        """Test case for stages_mtls_create

        """
        pass

    def test_stages_mtls_destroy(self) -> None:
        """Test case for stages_mtls_destroy

        """
        pass

    def test_stages_mtls_list(self) -> None:
        """Test case for stages_mtls_list

        """
        pass

    def test_stages_mtls_partial_update(self) -> None:
        """Test case for stages_mtls_partial_update

        """
        pass

    def test_stages_mtls_retrieve(self) -> None:
        """Test case for stages_mtls_retrieve

        """
        pass

    def test_stages_mtls_update(self) -> None:
        """Test case for stages_mtls_update

        """
        pass

    def test_stages_mtls_used_by_list(self) -> None:
        """Test case for stages_mtls_used_by_list

        """
        pass

    def test_stages_password_create(self) -> None:
        """Test case for stages_password_create

        """
        pass

    def test_stages_password_destroy(self) -> None:
        """Test case for stages_password_destroy

        """
        pass

    def test_stages_password_list(self) -> None:
        """Test case for stages_password_list

        """
        pass

    def test_stages_password_partial_update(self) -> None:
        """Test case for stages_password_partial_update

        """
        pass

    def test_stages_password_retrieve(self) -> None:
        """Test case for stages_password_retrieve

        """
        pass

    def test_stages_password_update(self) -> None:
        """Test case for stages_password_update

        """
        pass

    def test_stages_password_used_by_list(self) -> None:
        """Test case for stages_password_used_by_list

        """
        pass

    def test_stages_prompt_prompts_create(self) -> None:
        """Test case for stages_prompt_prompts_create

        """
        pass

    def test_stages_prompt_prompts_destroy(self) -> None:
        """Test case for stages_prompt_prompts_destroy

        """
        pass

    def test_stages_prompt_prompts_list(self) -> None:
        """Test case for stages_prompt_prompts_list

        """
        pass

    def test_stages_prompt_prompts_partial_update(self) -> None:
        """Test case for stages_prompt_prompts_partial_update

        """
        pass

    def test_stages_prompt_prompts_preview_create(self) -> None:
        """Test case for stages_prompt_prompts_preview_create

        """
        pass

    def test_stages_prompt_prompts_retrieve(self) -> None:
        """Test case for stages_prompt_prompts_retrieve

        """
        pass

    def test_stages_prompt_prompts_update(self) -> None:
        """Test case for stages_prompt_prompts_update

        """
        pass

    def test_stages_prompt_prompts_used_by_list(self) -> None:
        """Test case for stages_prompt_prompts_used_by_list

        """
        pass

    def test_stages_prompt_stages_create(self) -> None:
        """Test case for stages_prompt_stages_create

        """
        pass

    def test_stages_prompt_stages_destroy(self) -> None:
        """Test case for stages_prompt_stages_destroy

        """
        pass

    def test_stages_prompt_stages_list(self) -> None:
        """Test case for stages_prompt_stages_list

        """
        pass

    def test_stages_prompt_stages_partial_update(self) -> None:
        """Test case for stages_prompt_stages_partial_update

        """
        pass

    def test_stages_prompt_stages_retrieve(self) -> None:
        """Test case for stages_prompt_stages_retrieve

        """
        pass

    def test_stages_prompt_stages_update(self) -> None:
        """Test case for stages_prompt_stages_update

        """
        pass

    def test_stages_prompt_stages_used_by_list(self) -> None:
        """Test case for stages_prompt_stages_used_by_list

        """
        pass

    def test_stages_redirect_create(self) -> None:
        """Test case for stages_redirect_create

        """
        pass

    def test_stages_redirect_destroy(self) -> None:
        """Test case for stages_redirect_destroy

        """
        pass

    def test_stages_redirect_list(self) -> None:
        """Test case for stages_redirect_list

        """
        pass

    def test_stages_redirect_partial_update(self) -> None:
        """Test case for stages_redirect_partial_update

        """
        pass

    def test_stages_redirect_retrieve(self) -> None:
        """Test case for stages_redirect_retrieve

        """
        pass

    def test_stages_redirect_update(self) -> None:
        """Test case for stages_redirect_update

        """
        pass

    def test_stages_redirect_used_by_list(self) -> None:
        """Test case for stages_redirect_used_by_list

        """
        pass

    def test_stages_source_create(self) -> None:
        """Test case for stages_source_create

        """
        pass

    def test_stages_source_destroy(self) -> None:
        """Test case for stages_source_destroy

        """
        pass

    def test_stages_source_list(self) -> None:
        """Test case for stages_source_list

        """
        pass

    def test_stages_source_partial_update(self) -> None:
        """Test case for stages_source_partial_update

        """
        pass

    def test_stages_source_retrieve(self) -> None:
        """Test case for stages_source_retrieve

        """
        pass

    def test_stages_source_update(self) -> None:
        """Test case for stages_source_update

        """
        pass

    def test_stages_source_used_by_list(self) -> None:
        """Test case for stages_source_used_by_list

        """
        pass

    def test_stages_user_delete_create(self) -> None:
        """Test case for stages_user_delete_create

        """
        pass

    def test_stages_user_delete_destroy(self) -> None:
        """Test case for stages_user_delete_destroy

        """
        pass

    def test_stages_user_delete_list(self) -> None:
        """Test case for stages_user_delete_list

        """
        pass

    def test_stages_user_delete_partial_update(self) -> None:
        """Test case for stages_user_delete_partial_update

        """
        pass

    def test_stages_user_delete_retrieve(self) -> None:
        """Test case for stages_user_delete_retrieve

        """
        pass

    def test_stages_user_delete_update(self) -> None:
        """Test case for stages_user_delete_update

        """
        pass

    def test_stages_user_delete_used_by_list(self) -> None:
        """Test case for stages_user_delete_used_by_list

        """
        pass

    def test_stages_user_login_create(self) -> None:
        """Test case for stages_user_login_create

        """
        pass

    def test_stages_user_login_destroy(self) -> None:
        """Test case for stages_user_login_destroy

        """
        pass

    def test_stages_user_login_list(self) -> None:
        """Test case for stages_user_login_list

        """
        pass

    def test_stages_user_login_partial_update(self) -> None:
        """Test case for stages_user_login_partial_update

        """
        pass

    def test_stages_user_login_retrieve(self) -> None:
        """Test case for stages_user_login_retrieve

        """
        pass

    def test_stages_user_login_update(self) -> None:
        """Test case for stages_user_login_update

        """
        pass

    def test_stages_user_login_used_by_list(self) -> None:
        """Test case for stages_user_login_used_by_list

        """
        pass

    def test_stages_user_logout_create(self) -> None:
        """Test case for stages_user_logout_create

        """
        pass

    def test_stages_user_logout_destroy(self) -> None:
        """Test case for stages_user_logout_destroy

        """
        pass

    def test_stages_user_logout_list(self) -> None:
        """Test case for stages_user_logout_list

        """
        pass

    def test_stages_user_logout_partial_update(self) -> None:
        """Test case for stages_user_logout_partial_update

        """
        pass

    def test_stages_user_logout_retrieve(self) -> None:
        """Test case for stages_user_logout_retrieve

        """
        pass

    def test_stages_user_logout_update(self) -> None:
        """Test case for stages_user_logout_update

        """
        pass

    def test_stages_user_logout_used_by_list(self) -> None:
        """Test case for stages_user_logout_used_by_list

        """
        pass

    def test_stages_user_write_create(self) -> None:
        """Test case for stages_user_write_create

        """
        pass

    def test_stages_user_write_destroy(self) -> None:
        """Test case for stages_user_write_destroy

        """
        pass

    def test_stages_user_write_list(self) -> None:
        """Test case for stages_user_write_list

        """
        pass

    def test_stages_user_write_partial_update(self) -> None:
        """Test case for stages_user_write_partial_update

        """
        pass

    def test_stages_user_write_retrieve(self) -> None:
        """Test case for stages_user_write_retrieve

        """
        pass

    def test_stages_user_write_update(self) -> None:
        """Test case for stages_user_write_update

        """
        pass

    def test_stages_user_write_used_by_list(self) -> None:
        """Test case for stages_user_write_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
