# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DeliveryMethodEnum(str, Enum):
    """
    DeliveryMethodEnum
    """

    """
    allowed enum values
    """
    HTTPS_COLON_SLASH_SLASH_SCHEMAS_DOT_OPENID_DOT_NET_SLASH_SECEVENT_SLASH_RISC_SLASH_DELIVERY_MINUS_METHOD_SLASH_PUSH = 'https://schemas.openid.net/secevent/risc/delivery-method/push'
    HTTPS_COLON_SLASH_SLASH_SCHEMAS_DOT_OPENID_DOT_NET_SLASH_SECEVENT_SLASH_RISC_SLASH_DELIVERY_MINUS_METHOD_SLASH_POLL = 'https://schemas.openid.net/secevent/risc/delivery-method/poll'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DeliveryMethodEnum from a JSON string"""
        return cls(json.loads(json_str))


