# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.policies_api import PoliciesApi


class TestPoliciesApi(unittest.TestCase):
    """PoliciesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PoliciesApi()

    def tearDown(self) -> None:
        pass

    def test_policies_all_cache_clear_create(self) -> None:
        """Test case for policies_all_cache_clear_create

        """
        pass

    def test_policies_all_cache_info_retrieve(self) -> None:
        """Test case for policies_all_cache_info_retrieve

        """
        pass

    def test_policies_all_destroy(self) -> None:
        """Test case for policies_all_destroy

        """
        pass

    def test_policies_all_list(self) -> None:
        """Test case for policies_all_list

        """
        pass

    def test_policies_all_retrieve(self) -> None:
        """Test case for policies_all_retrieve

        """
        pass

    def test_policies_all_test_create(self) -> None:
        """Test case for policies_all_test_create

        """
        pass

    def test_policies_all_types_list(self) -> None:
        """Test case for policies_all_types_list

        """
        pass

    def test_policies_all_used_by_list(self) -> None:
        """Test case for policies_all_used_by_list

        """
        pass

    def test_policies_bindings_create(self) -> None:
        """Test case for policies_bindings_create

        """
        pass

    def test_policies_bindings_destroy(self) -> None:
        """Test case for policies_bindings_destroy

        """
        pass

    def test_policies_bindings_list(self) -> None:
        """Test case for policies_bindings_list

        """
        pass

    def test_policies_bindings_partial_update(self) -> None:
        """Test case for policies_bindings_partial_update

        """
        pass

    def test_policies_bindings_retrieve(self) -> None:
        """Test case for policies_bindings_retrieve

        """
        pass

    def test_policies_bindings_update(self) -> None:
        """Test case for policies_bindings_update

        """
        pass

    def test_policies_bindings_used_by_list(self) -> None:
        """Test case for policies_bindings_used_by_list

        """
        pass

    def test_policies_dummy_create(self) -> None:
        """Test case for policies_dummy_create

        """
        pass

    def test_policies_dummy_destroy(self) -> None:
        """Test case for policies_dummy_destroy

        """
        pass

    def test_policies_dummy_list(self) -> None:
        """Test case for policies_dummy_list

        """
        pass

    def test_policies_dummy_partial_update(self) -> None:
        """Test case for policies_dummy_partial_update

        """
        pass

    def test_policies_dummy_retrieve(self) -> None:
        """Test case for policies_dummy_retrieve

        """
        pass

    def test_policies_dummy_update(self) -> None:
        """Test case for policies_dummy_update

        """
        pass

    def test_policies_dummy_used_by_list(self) -> None:
        """Test case for policies_dummy_used_by_list

        """
        pass

    def test_policies_event_matcher_create(self) -> None:
        """Test case for policies_event_matcher_create

        """
        pass

    def test_policies_event_matcher_destroy(self) -> None:
        """Test case for policies_event_matcher_destroy

        """
        pass

    def test_policies_event_matcher_list(self) -> None:
        """Test case for policies_event_matcher_list

        """
        pass

    def test_policies_event_matcher_partial_update(self) -> None:
        """Test case for policies_event_matcher_partial_update

        """
        pass

    def test_policies_event_matcher_retrieve(self) -> None:
        """Test case for policies_event_matcher_retrieve

        """
        pass

    def test_policies_event_matcher_update(self) -> None:
        """Test case for policies_event_matcher_update

        """
        pass

    def test_policies_event_matcher_used_by_list(self) -> None:
        """Test case for policies_event_matcher_used_by_list

        """
        pass

    def test_policies_expression_create(self) -> None:
        """Test case for policies_expression_create

        """
        pass

    def test_policies_expression_destroy(self) -> None:
        """Test case for policies_expression_destroy

        """
        pass

    def test_policies_expression_list(self) -> None:
        """Test case for policies_expression_list

        """
        pass

    def test_policies_expression_partial_update(self) -> None:
        """Test case for policies_expression_partial_update

        """
        pass

    def test_policies_expression_retrieve(self) -> None:
        """Test case for policies_expression_retrieve

        """
        pass

    def test_policies_expression_update(self) -> None:
        """Test case for policies_expression_update

        """
        pass

    def test_policies_expression_used_by_list(self) -> None:
        """Test case for policies_expression_used_by_list

        """
        pass

    def test_policies_geoip_create(self) -> None:
        """Test case for policies_geoip_create

        """
        pass

    def test_policies_geoip_destroy(self) -> None:
        """Test case for policies_geoip_destroy

        """
        pass

    def test_policies_geoip_iso3166_list(self) -> None:
        """Test case for policies_geoip_iso3166_list

        """
        pass

    def test_policies_geoip_list(self) -> None:
        """Test case for policies_geoip_list

        """
        pass

    def test_policies_geoip_partial_update(self) -> None:
        """Test case for policies_geoip_partial_update

        """
        pass

    def test_policies_geoip_retrieve(self) -> None:
        """Test case for policies_geoip_retrieve

        """
        pass

    def test_policies_geoip_update(self) -> None:
        """Test case for policies_geoip_update

        """
        pass

    def test_policies_geoip_used_by_list(self) -> None:
        """Test case for policies_geoip_used_by_list

        """
        pass

    def test_policies_password_create(self) -> None:
        """Test case for policies_password_create

        """
        pass

    def test_policies_password_destroy(self) -> None:
        """Test case for policies_password_destroy

        """
        pass

    def test_policies_password_expiry_create(self) -> None:
        """Test case for policies_password_expiry_create

        """
        pass

    def test_policies_password_expiry_destroy(self) -> None:
        """Test case for policies_password_expiry_destroy

        """
        pass

    def test_policies_password_expiry_list(self) -> None:
        """Test case for policies_password_expiry_list

        """
        pass

    def test_policies_password_expiry_partial_update(self) -> None:
        """Test case for policies_password_expiry_partial_update

        """
        pass

    def test_policies_password_expiry_retrieve(self) -> None:
        """Test case for policies_password_expiry_retrieve

        """
        pass

    def test_policies_password_expiry_update(self) -> None:
        """Test case for policies_password_expiry_update

        """
        pass

    def test_policies_password_expiry_used_by_list(self) -> None:
        """Test case for policies_password_expiry_used_by_list

        """
        pass

    def test_policies_password_list(self) -> None:
        """Test case for policies_password_list

        """
        pass

    def test_policies_password_partial_update(self) -> None:
        """Test case for policies_password_partial_update

        """
        pass

    def test_policies_password_retrieve(self) -> None:
        """Test case for policies_password_retrieve

        """
        pass

    def test_policies_password_update(self) -> None:
        """Test case for policies_password_update

        """
        pass

    def test_policies_password_used_by_list(self) -> None:
        """Test case for policies_password_used_by_list

        """
        pass

    def test_policies_reputation_create(self) -> None:
        """Test case for policies_reputation_create

        """
        pass

    def test_policies_reputation_destroy(self) -> None:
        """Test case for policies_reputation_destroy

        """
        pass

    def test_policies_reputation_list(self) -> None:
        """Test case for policies_reputation_list

        """
        pass

    def test_policies_reputation_partial_update(self) -> None:
        """Test case for policies_reputation_partial_update

        """
        pass

    def test_policies_reputation_retrieve(self) -> None:
        """Test case for policies_reputation_retrieve

        """
        pass

    def test_policies_reputation_scores_destroy(self) -> None:
        """Test case for policies_reputation_scores_destroy

        """
        pass

    def test_policies_reputation_scores_list(self) -> None:
        """Test case for policies_reputation_scores_list

        """
        pass

    def test_policies_reputation_scores_retrieve(self) -> None:
        """Test case for policies_reputation_scores_retrieve

        """
        pass

    def test_policies_reputation_scores_used_by_list(self) -> None:
        """Test case for policies_reputation_scores_used_by_list

        """
        pass

    def test_policies_reputation_update(self) -> None:
        """Test case for policies_reputation_update

        """
        pass

    def test_policies_reputation_used_by_list(self) -> None:
        """Test case for policies_reputation_used_by_list

        """
        pass

    def test_policies_unique_password_create(self) -> None:
        """Test case for policies_unique_password_create

        """
        pass

    def test_policies_unique_password_destroy(self) -> None:
        """Test case for policies_unique_password_destroy

        """
        pass

    def test_policies_unique_password_list(self) -> None:
        """Test case for policies_unique_password_list

        """
        pass

    def test_policies_unique_password_partial_update(self) -> None:
        """Test case for policies_unique_password_partial_update

        """
        pass

    def test_policies_unique_password_retrieve(self) -> None:
        """Test case for policies_unique_password_retrieve

        """
        pass

    def test_policies_unique_password_update(self) -> None:
        """Test case for policies_unique_password_update

        """
        pass

    def test_policies_unique_password_used_by_list(self) -> None:
        """Test case for policies_unique_password_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
