# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.events_api import EventsApi


class TestEventsApi(unittest.TestCase):
    """EventsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventsApi()

    def tearDown(self) -> None:
        pass

    def test_events_events_actions_list(self) -> None:
        """Test case for events_events_actions_list

        """
        pass

    def test_events_events_create(self) -> None:
        """Test case for events_events_create

        """
        pass

    def test_events_events_destroy(self) -> None:
        """Test case for events_events_destroy

        """
        pass

    def test_events_events_list(self) -> None:
        """Test case for events_events_list

        """
        pass

    def test_events_events_partial_update(self) -> None:
        """Test case for events_events_partial_update

        """
        pass

    def test_events_events_retrieve(self) -> None:
        """Test case for events_events_retrieve

        """
        pass

    def test_events_events_top_per_user_list(self) -> None:
        """Test case for events_events_top_per_user_list

        """
        pass

    def test_events_events_update(self) -> None:
        """Test case for events_events_update

        """
        pass

    def test_events_events_volume_list(self) -> None:
        """Test case for events_events_volume_list

        """
        pass

    def test_events_notifications_destroy(self) -> None:
        """Test case for events_notifications_destroy

        """
        pass

    def test_events_notifications_list(self) -> None:
        """Test case for events_notifications_list

        """
        pass

    def test_events_notifications_mark_all_seen_create(self) -> None:
        """Test case for events_notifications_mark_all_seen_create

        """
        pass

    def test_events_notifications_partial_update(self) -> None:
        """Test case for events_notifications_partial_update

        """
        pass

    def test_events_notifications_retrieve(self) -> None:
        """Test case for events_notifications_retrieve

        """
        pass

    def test_events_notifications_update(self) -> None:
        """Test case for events_notifications_update

        """
        pass

    def test_events_notifications_used_by_list(self) -> None:
        """Test case for events_notifications_used_by_list

        """
        pass

    def test_events_rules_create(self) -> None:
        """Test case for events_rules_create

        """
        pass

    def test_events_rules_destroy(self) -> None:
        """Test case for events_rules_destroy

        """
        pass

    def test_events_rules_list(self) -> None:
        """Test case for events_rules_list

        """
        pass

    def test_events_rules_partial_update(self) -> None:
        """Test case for events_rules_partial_update

        """
        pass

    def test_events_rules_retrieve(self) -> None:
        """Test case for events_rules_retrieve

        """
        pass

    def test_events_rules_update(self) -> None:
        """Test case for events_rules_update

        """
        pass

    def test_events_rules_used_by_list(self) -> None:
        """Test case for events_rules_used_by_list

        """
        pass

    def test_events_system_tasks_list(self) -> None:
        """Test case for events_system_tasks_list

        """
        pass

    def test_events_system_tasks_retrieve(self) -> None:
        """Test case for events_system_tasks_retrieve

        """
        pass

    def test_events_system_tasks_run_create(self) -> None:
        """Test case for events_system_tasks_run_create

        """
        pass

    def test_events_transports_create(self) -> None:
        """Test case for events_transports_create

        """
        pass

    def test_events_transports_destroy(self) -> None:
        """Test case for events_transports_destroy

        """
        pass

    def test_events_transports_list(self) -> None:
        """Test case for events_transports_list

        """
        pass

    def test_events_transports_partial_update(self) -> None:
        """Test case for events_transports_partial_update

        """
        pass

    def test_events_transports_retrieve(self) -> None:
        """Test case for events_transports_retrieve

        """
        pass

    def test_events_transports_test_create(self) -> None:
        """Test case for events_transports_test_create

        """
        pass

    def test_events_transports_update(self) -> None:
        """Test case for events_transports_update

        """
        pass

    def test_events_transports_used_by_list(self) -> None:
        """Test case for events_transports_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
