# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.system_info_runtime import SystemInfoRuntime

class TestSystemInfoRuntime(unittest.TestCase):
    """SystemInfoRuntime unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemInfoRuntime:
        """Test SystemInfoRuntime
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemInfoRuntime`
        """
        model = SystemInfoRuntime()
        if include_optional:
            return SystemInfoRuntime(
                python_version = '',
                environment = '',
                architecture = '',
                platform = '',
                uname = '',
                openssl_version = '',
                openssl_fips_enabled = True,
                authentik_version = ''
            )
        else:
            return SystemInfoRuntime(
                python_version = '',
                environment = '',
                architecture = '',
                platform = '',
                uname = '',
                openssl_version = '',
                openssl_fips_enabled = True,
                authentik_version = '',
        )
        """

    def testSystemInfoRuntime(self):
        """Test SystemInfoRuntime"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
