# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.user_consent import UserConsent

class TestUserConsent(unittest.TestCase):
    """UserConsent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserConsent:
        """Test UserConsent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserConsent`
        """
        model = UserConsent()
        if include_optional:
            return UserConsent(
                pk = 56,
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expiring = True,
                user = authentik_client.models.user.User(
                    pk = 56, 
                    username = '', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    date_joined = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_superuser = True, 
                    groups = [
                        ''
                        ], 
                    groups_obj = [
                        authentik_client.models.user_group.UserGroup(
                            pk = '', 
                            num_pk = 56, 
                            name = '', 
                            is_superuser = True, 
                            parent = '', 
                            parent_name = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], 
                    email = '', 
                    avatar = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', 
                    path = '', 
                    type = 'internal', 
                    uuid = '', 
                    password_change_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                application = authentik_client.models.application.Application(
                    pk = '', 
                    name = '', 
                    slug = 'z', 
                    provider = 56, 
                    provider_obj = null, 
                    backchannel_providers = [
                        56
                        ], 
                    backchannel_providers_obj = [
                        authentik_client.models.provider.Provider(
                            pk = 56, 
                            name = '', 
                            authentication_flow = '', 
                            authorization_flow = '', 
                            invalidation_flow = '', 
                            property_mappings = [
                                ''
                                ], 
                            component = '', 
                            assigned_application_slug = '', 
                            assigned_application_name = '', 
                            assigned_backchannel_application_slug = '', 
                            assigned_backchannel_application_name = '', 
                            verbose_name = '', 
                            verbose_name_plural = '', 
                            meta_model_name = '', )
                        ], 
                    launch_url = '', 
                    open_in_new_tab = True, 
                    meta_launch_url = '', 
                    meta_icon = '', 
                    meta_description = '', 
                    meta_publisher = '', 
                    policy_engine_mode = 'all', 
                    group = '', ),
                permissions = ''
            )
        else:
            return UserConsent(
                pk = 56,
                user = authentik_client.models.user.User(
                    pk = 56, 
                    username = '', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    date_joined = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_superuser = True, 
                    groups = [
                        ''
                        ], 
                    groups_obj = [
                        authentik_client.models.user_group.UserGroup(
                            pk = '', 
                            num_pk = 56, 
                            name = '', 
                            is_superuser = True, 
                            parent = '', 
                            parent_name = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], 
                    email = '', 
                    avatar = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', 
                    path = '', 
                    type = 'internal', 
                    uuid = '', 
                    password_change_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                application = authentik_client.models.application.Application(
                    pk = '', 
                    name = '', 
                    slug = 'z', 
                    provider = 56, 
                    provider_obj = null, 
                    backchannel_providers = [
                        56
                        ], 
                    backchannel_providers_obj = [
                        authentik_client.models.provider.Provider(
                            pk = 56, 
                            name = '', 
                            authentication_flow = '', 
                            authorization_flow = '', 
                            invalidation_flow = '', 
                            property_mappings = [
                                ''
                                ], 
                            component = '', 
                            assigned_application_slug = '', 
                            assigned_application_name = '', 
                            assigned_backchannel_application_slug = '', 
                            assigned_backchannel_application_name = '', 
                            verbose_name = '', 
                            verbose_name_plural = '', 
                            meta_model_name = '', )
                        ], 
                    launch_url = '', 
                    open_in_new_tab = True, 
                    meta_launch_url = '', 
                    meta_icon = '', 
                    meta_description = '', 
                    meta_publisher = '', 
                    policy_engine_mode = 'all', 
                    group = '', ),
        )
        """

    def testUserConsent(self):
        """Test UserConsent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
