# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.flow_inspection import FlowInspection

class TestFlowInspection(unittest.TestCase):
    """FlowInspection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowInspection:
        """Test FlowInspection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowInspection`
        """
        model = FlowInspection()
        if include_optional:
            return FlowInspection(
                plans = [
                    authentik_client.models.flow_inspector_plan.FlowInspectorPlan(
                        current_stage = null, 
                        next_planned_stage = null, 
                        plan_context = {
                            'key' : null
                            }, 
                        session_id = '', )
                    ],
                current_plan = authentik_client.models.flow_inspector_plan.FlowInspectorPlan(
                    current_stage = null, 
                    next_planned_stage = null, 
                    plan_context = {
                        'key' : null
                        }, 
                    session_id = '', ),
                is_completed = True
            )
        else:
            return FlowInspection(
                plans = [
                    authentik_client.models.flow_inspector_plan.FlowInspectorPlan(
                        current_stage = null, 
                        next_planned_stage = null, 
                        plan_context = {
                            'key' : null
                            }, 
                        session_id = '', )
                    ],
                is_completed = True,
        )
        """

    def testFlowInspection(self):
        """Test FlowInspection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
