# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.system_info import SystemInfo

class TestSystemInfo(unittest.TestCase):
    """SystemInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemInfo:
        """Test SystemInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemInfo`
        """
        model = SystemInfo()
        if include_optional:
            return SystemInfo(
                http_headers = {
                    'key' : ''
                    },
                http_host = '',
                http_is_secure = True,
                runtime = authentik_client.models.system_info_runtime.SystemInfo_runtime(
                    python_version = '', 
                    environment = '', 
                    architecture = '', 
                    platform = '', 
                    uname = '', 
                    openssl_version = '', 
                    openssl_fips_enabled = True, 
                    authentik_version = '', ),
                brand = '',
                server_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                embedded_outpost_disabled = True,
                embedded_outpost_host = ''
            )
        else:
            return SystemInfo(
                http_headers = {
                    'key' : ''
                    },
                http_host = '',
                http_is_secure = True,
                runtime = authentik_client.models.system_info_runtime.SystemInfo_runtime(
                    python_version = '', 
                    environment = '', 
                    architecture = '', 
                    platform = '', 
                    uname = '', 
                    openssl_version = '', 
                    openssl_fips_enabled = True, 
                    authentik_version = '', ),
                brand = '',
                server_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                embedded_outpost_disabled = True,
                embedded_outpost_host = '',
        )
        """

    def testSystemInfo(self):
        """Test SystemInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
