# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.google_workspace_provider_group import GoogleWorkspaceProviderGroup

class TestGoogleWorkspaceProviderGroup(unittest.TestCase):
    """GoogleWorkspaceProviderGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleWorkspaceProviderGroup:
        """Test GoogleWorkspaceProviderGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleWorkspaceProviderGroup`
        """
        model = GoogleWorkspaceProviderGroup()
        if include_optional:
            return GoogleWorkspaceProviderGroup(
                id = '',
                google_id = '',
                group = '',
                group_obj = authentik_client.models.user_group.UserGroup(
                    pk = '', 
                    num_pk = 56, 
                    name = '', 
                    is_superuser = True, 
                    parent = '', 
                    parent_name = '', 
                    attributes = {
                        'key' : null
                        }, ),
                provider = 56,
                attributes = {
                    'key' : null
                    }
            )
        else:
            return GoogleWorkspaceProviderGroup(
                id = '',
                google_id = '',
                group = '',
                group_obj = authentik_client.models.user_group.UserGroup(
                    pk = '', 
                    num_pk = 56, 
                    name = '', 
                    is_superuser = True, 
                    parent = '', 
                    parent_name = '', 
                    attributes = {
                        'key' : null
                        }, ),
                provider = 56,
                attributes = {
                    'key' : null
                    },
        )
        """

    def testGoogleWorkspaceProviderGroup(self):
        """Test GoogleWorkspaceProviderGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
